@@ -129,7 +129,7 @@ class LUTCanvas(plot.PlotCanvas):
 
 	def __init__(self, *args, **kwargs):
 		self.colors = {"RGB_R": "red",
-					   "RGB_G": "green",
+					   "RGB_G": "#00FF00",
 					   "RGB_B": "#0080FF",
 					   "CMYK_C": "cyan",
 					   "CMYK_M": "magenta",
@@ -140,13 +140,13 @@ class LUTCanvas(plot.PlotCanvas):
 					   "nCLR_2": "yellow",
 					   "nCLR_3": "black",
 					   "nCLR_4": "red",
-					   "nCLR_5": "green",
+					   "nCLR_5": "#00FF00",
 					   "nCLR_6": "blue",
 					   "nCLR_7": "#FF8000",
 					   "nCLR_8": "#80FF00",
 					   "nCLR_9": "#00FF80",
 					   "XYZ_X": "red",
-					   "XYZ_Y": "green",
+					   "XYZ_Y": "#00FF00",
 					   "XYZ_Z": "#0080FF",
 					   "Lab_L*": "#CCCCCC",
 					   "Lab_a*": "#FF0080",
@@ -303,12 +303,12 @@ class LUTCanvas(plot.PlotCanvas):
 						n = colormath.XYZ2Lab(0, float(n) / axis_x * 100, 0)[0] * (axis_x / 100.0)
 					if connection_colorspace in ("Lab", "XYZ"):
 						points[channel].append([n, i])
-						idx = int(round(n / 255.0 * 4095))
+						idx = int(round(float(n) / 255.0 * 4095))
 						self.point_grid[channel][idx] = i
 					else:
 						points[channel].append([i, n])
 						idx = int(round(i / 255.0 * 4095))
-						self.point_grid[channel][idx] = n
+						self.point_grid[channel][idx] = float(n)
 
 		#for n in sorted(self.point_grid[0].keys()):
 			#print n, self.point_grid[0].get(n), self.point_grid[1].get(n), self.point_grid[2].get(n)
@@ -334,30 +334,27 @@ class LUTCanvas(plot.PlotCanvas):
 		legend = []
 		color = 'white'
 			
-		identical = (len(points) > 1 and
-					 all(values == points.values()[0] for values in points.itervalues()))
+		if len(points) > 1:
+			values0 = points.values()[0]
+			# identical = all(values == values0
+							# for values in points.itervalues())
+			identical = (all(all(x == values0[i][0] and
+								 abs(y - values0[i][1]) < 0.005
+								 for i, (x, y) in enumerate(values))
+							 for values in points.itervalues()))
+		else:
+			identical = False
 
 		if identical:
 			channels_label = "".join(channels.values())
-			if channels_label in ("RGB", "CMYK"):
-				color = 'white'
-			elif channels_label == "RG":
-				color = 'yellow'
-			elif channels_label == "RB":
-				color = 'magenta'
-			elif channels_label == "GB":
-				color = 'cyan'
-			elif channels_label == "CM":
-				color = '#0080FF'
-			elif channels_label == "CY":
-				color = 'green'
-			elif channels_label == "MY":
-				color = 'red'
+			color = self.get_color(channels_label, color)
 		for channel_name in channels.values():
 			if channel_name:
 				legend.append(channel_name)
 		linear_points = [(i, int(round(v / axis_y * maxv))) for i, v in
 						 linear_points]
+		seen_values = []
+		seen_labels = []
 		for channel, values in points.iteritems():
 			channel_label = channels[channel]
 			if not identical:
@@ -391,15 +388,36 @@ class LUTCanvas(plot.PlotCanvas):
 					self.point_grid[channel][idx] = center_y
 					color2 = self.colors["Lab_%s-" % channel_label]
 					line2 = Plot(values2, legend=label + suffix, colour=color2)
+				elif seen_values:
+					# Check if same line (+- 0.005 tolerance) has been seen
+					for idx, seen in enumerate(seen_values):
+						match = True
+						for i, (x, y) in enumerate(seen):
+							if x != values[i][0] or abs(y - values[i][1]) > 0.005:
+								match = False
+								break
+						if match:
+							break
+					else:
+						match = False
+					if match:
+						seen_label = seen_labels[idx]
+						lines[idx + 1].attributes["colour"] = self.get_color(seen_label +
+																			 channel_label)
+						continue
 			line = Plot(values, legend=label + suffix, colour=color)
 			if ((colorspace == "CMYK" and label == "K") or
 				(colorspace == "Lab" and label in ("a*", "b*"))):
 				# CMYK -> KCMY, Lab -> baL for better visibilty
 				lines.insert(1, line)
+				seen_values.insert(0, values)
+				seen_labels.insert(0, label)
 				if line2:
 					lines.insert(1, line2)
 			else:
 				lines.append(line)
+				seen_values.append(values)
+				seen_labels.append(label)
 				if line2:
 					lines.append(line2)
 			if identical:
@@ -411,6 +429,23 @@ class LUTCanvas(plot.PlotCanvas):
 										   " ".join([yLabel,
 													 lang.getstr("out")])))
 
+	def get_color(self, channels_label, default="white"):
+		if channels_label in ("RGB", "CMYK", "XYZ"):
+			return 'white'
+		elif channels_label in ("RG", "XY"):
+			return 'yellow'
+		elif channels_label in ("RB", "XZ"):
+			return 'magenta'
+		elif channels_label in ("GB", "YZ"):
+			return 'cyan'
+		elif channels_label == "CM":
+			return '#0080FF'
+		elif channels_label == "CY":
+			return '#00FF00'
+		elif channels_label == "MY":
+			return 'red'
+		return default
+
 	def DrawPointLabel(self, dc, mDataDict):
 		"""
 		Draw point labels.
@@ -859,8 +894,8 @@ class LUTFrame(BaseFrame):
 		self.SetSaneGeometry(
 			getcfg("position.lut_viewer.x"), 
 			getcfg("position.lut_viewer.y"), 
-			getcfg("size.lut_viewer.w") + border * 2, 
-			getcfg("size.lut_viewer.h") + titlebar + border)
+			getcfg("size.lut_viewer.w"), 
+			getcfg("size.lut_viewer.h"))
 		
 		self.Bind(wx.EVT_MOVE, self.OnMove)
 		self.Bind(wx.EVT_SIZE, self.OnSize)
@@ -1380,7 +1415,8 @@ class LUTFrame(BaseFrame):
 			setattr(self, "tf_" + channel + "TRC", trc)
 		self.trc = None
 		curves = []
-		if "vcgt" in profile.tags or "MS00" in profile.tags:
+		if ("vcgt" in profile.tags or "MS00" in profile.tags or
+			self.__class__ is LUTFrame):
 			curves.append(lang.getstr('vcgt'))
 		self.client.errors = []
 		self.toggle_clut.SetValue("B2A0" in profile.tags or
@@ -1401,6 +1437,7 @@ class LUTFrame(BaseFrame):
 		if curves and not self.plot_mode_select.SetStringSelection(selection):
 			self.plot_mode_select.SetSelection(0)
 			center = True
+		self.plot_mode_select.ContainingSizer.Layout()
 		self.cbox_sizer.Layout()
 		self.box_sizer.Layout()
 		self.DrawLUT()
@@ -1837,10 +1874,9 @@ class LUTFrame(BaseFrame):
 	def OnSize(self, event=None):
 		if self.IsShownOnScreen() and not \
 		   self.IsMaximized() and not self.IsIconized():
-			w, h = self.GetSize()
-			border, titlebar = get_platform_window_decoration_size()
-			setcfg("size.lut_viewer.w", w - border * 2)
-			setcfg("size.lut_viewer.h", h - titlebar - border)
+			w, h = self.ClientSize
+			setcfg("size.lut_viewer.w", w)
+			setcfg("size.lut_viewer.h", h)
 		if event:
 			event.Skip()
 			if sys.platform == "win32":
@@ -2081,11 +2117,12 @@ def _main(app):
 	app.TopWindow.display_no, geometry, client_area = app.TopWindow.get_display()
 	app.TopWindow.Bind(wx.EVT_MOVE, app.TopWindow.move_handler, app.TopWindow)
 	display_no = get_argyll_display_number(geometry)
-	setcfg("display.number", display_no + 1)
+	if display_no is not None:
+		setcfg("display.number", display_no + 1)
 	app.TopWindow.update_controls()
 	for arg in sys.argv[1:]:
 		if os.path.isfile(arg):
-			app.TopWindow.drop_handler(safe_unicode(arg))
+			app.TopWindow.drop_handler(safe_unicode(os.path.abspath(arg)))
 			break
 	else:
 		app.TopWindow.load_lut(get_display_profile(display_no))
